# Sequence containers

## Alphabet
![mkapi](picea.Alphabet)

## alphabets
![mkapi](picea.sequence.Alphabets)

## Sequence
![mkapi](picea.Sequence)

## AbstractSequenceCollection
![mkapi](picea.AbstractSequenceCollection)

## SequenceCollection
![mkapi](picea.SequenceCollection)

## MultipleSequenceAlignment
![mkapi](picea.MultipleSequenceAlignment)

## SequenceAnnotation
![mkapi](picea.SequenceAnnotation)